import torch
from EIVData.csv_dataset import CSVData
from torch.utils.data import random_split

def load_data(seed=0, splitting_part=0.8, normalize=True):
    """
    Loads the energy efficiency dataset
    :param seed: Seed for splitting and shuffling the data.
    Defaults to 0.
    :param splitting_part: Which fraction of the data to use as training
    data. Defaults to 0.8.
    :normalize: Whether to normalize the data, defaults to True.
    :returns: energy_trainset, energy_testset
    """
    energy_dataset = CSVData('~/SharedData/AI/datasets/energy_efficiency/ENB2012_data.csv',
            class_name=['Y1', 'Y2'],
            shuffle_seed=seed,
            normalize=normalize)
    dataset_len = len(energy_dataset)
    train_len = int(dataset_len*splitting_part)
    test_len = dataset_len - train_len
    energy_trainset, energy_testset = random_split(energy_dataset,
            lengths=[train_len, test_len],
            generator=torch.Generator().manual_seed(seed))
    return energy_trainset, energy_testset
